@@ -7,6 +7,7 @@ import warnings
 from collections import OrderedDict
 from collections.abc import Mapping
 from collections.abc import MutableMapping
+from contextlib import contextmanager
 from functools import partial
 from logging import BASIC_FORMAT
 from logging import PercentStyle as _PercentStyle
@@ -80,6 +81,26 @@ else:
         validation_pattern = re.compile(r'{[a-z_]\w*}', re.I)
 
 
+# python3.7 logging introduced _lock, python3.13 removed _acquireLock/_releaseLock
+if sys.version_info.major >= 3 and sys.version_info.minor >= 7:
+
+    @contextmanager
+    def logging_lock():
+        # pylint: disable=protected-access
+        with logging._lock:
+            yield
+else:
+
+    @contextmanager
+    def logging_lock():
+        # pylint: disable=protected-access,no-member
+        logging._acquireLock()
+        try:
+            yield
+        finally:
+            logging._releaseLock()
+
+
 class EnhancedPercentStyle(PercentStyle):
     validation_pattern = re.compile(
         r'%\([\w\.]+\)[#0+ -]*(\*|\d+)?(\.(\*|\d+))?[diouxefgcrsa%]', re.I
@@ -343,21 +364,19 @@ class JsonFormatter(logging.Formatter):
         if self.add_always_extra:
             extra = self._get_extra_attrs(record)
 
-        message = self.formatMessage(record)
-
-        if self.add_always_extra:
-            self._add_extra_to_message(extra, message)
-
         if record.exc_info:
             # Cache the traceback text to avoid converting it multiple times
             # (it's constant anyway)
             if not record.exc_text:
                 record.exc_text = self.formatException(record.exc_info)
-        if record.exc_text:
-            message['exc_text'] = record.exc_text
 
         if record.stack_info:
-            message['stack_info'] = self.formatStack(record.stack_info)
+            record.stack_info = self.formatStack(record.stack_info)
+
+        message = self.formatMessage(record)
+
+        if self.add_always_extra:
+            self._add_extra_to_message(extra, message)
 
         # When adding all extras, to avoid crash when a log message adds an extra with a non
         # serializable object, we add a default serializer.
@@ -420,8 +439,7 @@ def basic_config(**kwargs):  # pragma: no cover
     # Add thread safety in case someone mistakenly calls
     # basic_config() from multiple threads
     # pylint: disable=protected-access
-    logging._acquireLock()
-    try:
+    with logging_lock():
         if len(logging.root.handlers) > 0:
             return
 
@@ -459,5 +477,3 @@ def basic_config(**kwargs):  # pragma: no cover
         if kwargs:
             keys = ', '.join(kwargs.keys())
             raise ValueError('Unrecognized argument(s): %s' % keys)
-    finally:
-        logging._releaseLock()
