@@ -10,6 +10,7 @@ from nose2.tools import params
 
 from logging_utilities.filters import ConstAttribute
 from logging_utilities.formatters.json_formatter import JsonFormatter
+from logging_utilities.formatters.json_formatter import basic_config
 
 # From python3.7, dict is ordered
 if sys.version_info.major >= 3 and sys.version_info.minor >= 7:
@@ -18,6 +19,7 @@ else:
     dictionary = OrderedDict
 
 
+# pylint: disable=too-many-public-methods
 class BasicJsonFormatterTest(unittest.TestCase):
     maxDiff = None
 
@@ -378,11 +380,8 @@ class BasicJsonFormatterTest(unittest.TestCase):
             logger = logging.getLogger('test_formatter')
             self._configure_logger(
                 logger,
-                fmt=dictionary([
-                    ('levelname', 'levelname'),
-                    ('name', 'name'),
-                    ('message', 'message'),
-                ])
+                fmt=dictionary([('levelname', 'levelname'), ('name', 'name'),
+                                ('message', 'message'), ('stack_info', 'stack_info')])
             )
             logger.info('Message with stack info', stack_info=True)
         message = json.loads(ctx.output[0], object_pairs_hook=dictionary)
@@ -787,3 +786,87 @@ class BasicJsonFormatterTest(unittest.TestCase):
                 ("message", "Composed message without extra"),
             ])
         )
+
+    def test_exc_info_without_configuration(self):
+        """
+        Test that the exc_text doesn't appear if it's not configured
+        in the logger, even though the logging call records it
+        """
+        with self.assertLogs('test_formatter', level=logging.DEBUG) as ctx:
+            logger = logging.getLogger('test_formatter')
+            self._configure_logger(
+                logger,
+                fmt=dictionary([
+                    ('level', 'levelname'),
+                    ('request', ['request.path', 'request.method']),
+                    ('message', 'message'),
+                ]),
+                remove_empty=True,
+                ignore_missing=True
+            )
+
+            try:
+                raise Exception("Error occurred")  # pylint: disable=broad-exception-raised
+            except Exception as err:  # pylint: disable=broad-except
+                logger.critical(
+                    str(err),
+                    exc_info=sys.exc_info(),
+                    extra={'request': {
+                        'path': '/my/path', 'method': 'GET', 'scheme': 'https'
+                    }}
+                )
+
+        self.assertDictEqual(
+            json.loads(ctx.output[0], object_pairs_hook=dictionary),
+            dictionary([
+                ("level", "CRITICAL"),
+                ("request", ["/my/path", "GET"]),
+                ("message", "Error occurred"),  # no exc_text because it wasn't configured
+            ])
+        )
+
+    def test_stack_info_without_configuration(self):
+        """
+        Test that the stack_info doesn't appear in the record when it's
+        not configured, even though the log call records it
+        """
+        with self.assertLogs('test_formatter', level=logging.DEBUG) as ctx:
+            logger = logging.getLogger('test_formatter')
+            self._configure_logger(
+                logger,
+                fmt=dictionary([
+                    ('level', 'levelname'),
+                    ('request', ['request.path', 'request.method']),
+                    ('message', 'message'),
+                ]),
+                remove_empty=True,
+                ignore_missing=True
+            )
+
+            logger.info(
+                "Stack isn't wished for here",
+                exc_info=sys.exc_info(),
+                extra={'request': {
+                    'path': '/my/path', 'method': 'GET', 'scheme': 'https'
+                }},
+                # record the stack_info
+                stack_info=True
+            )
+
+        self.assertDictEqual(
+            json.loads(ctx.output[0], object_pairs_hook=dictionary),
+            dictionary([
+                ("level", "INFO"),
+                ("request", ["/my/path", "GET"]),
+                ("message",
+                 "Stack isn't wished for here"),  # no stack_info because it wasn't configured
+            ])
+        )
+
+    def test_base_config_already_configure(self):
+        """
+        Test if base_config is skipped if already configured
+        """
+        self.assertEqual(len(logging.root.handlers), 1)
+        basic_config(level=logging.INFO)
+        self.assertNotIsInstance(logging.root.handlers[0], logging.StreamHandler)
